\ Do not use this file except in compliance with the License. You may
\ obtain a copy of the License at http://www.microcore.org/License/
\ Software distributed under the License is distributed on an "AS IS" basis,
\ WITHOUT WARRANTY OF ANY KIND, either express or implied.
\ See the License for the specific language governing rights and limitations
\ under the License.
\
\ The Original Code is: MicroCore LOAD_DEBUG.F 1.20
\
\ The Initial Developer of the Original Code is Klaus.Schleisiek AT hamburg.de.
\ Port to the gforth system and extensions by Ulrich.E.Hoffmann AT xlerb.de 
\
\ Introduction  see: doc/uCore_Introduction.pdf
\ Tools         see: doc/uCore_Implementation.pdf
\ Versions      see: uCross_Versions.txt
\ License       see: doc/uCore_License.pdf
\ Conventions   see: doc/uCore_Conventions.pdf
\ Contributors  see: doc/uCore_Contributors.pdf
\
\ MicroCore load screen for the core with debug interface
\ used to generate DEBUG_PROGRAM.VHD for the COMP_DEBUG.DO simulator load macro
\
Forth definitions decimal

true  Constant DEBUGGING immediate     \ Include debug words for the cross-compiler?

true  Constant WITH_LOCALS immediate   \ RSP-offset LOCAL addressing?
true  Constant WITH_TASKS immediate    \ base-offset TASK addressing?
true  Constant WITH_NOS immediate      \ with NOS register?
true  Constant WITH_TOR immediate      \ with TOR register?
true  Constant WITH_IP immediate       \ with IP register for threaded code interpretation?
true  Constant WITH_TOKENS immediate   \ with token threaded code support?
true  Constant VAN_NEUMANN immediate   \ read/writeable program memory?

   14 Constant #prog_addr_width        \ Limit size of Target program memory image to a sensible number
   16 Constant #data                   \ CONSTANTS.VHD at most 4096 addresses for 12 bits, etc. This value is freely scaleable
                                       \ the cross-compiler supports at most 32 bits
    3 Constant #usr_vect_width         \ actual width is 2 ** #usr_vect_width

include microcore.f                    \ the cross-compiler
include disasm.f                       \ the disassembler

Create Image                           \ a "marker". See MICROCORE.F for its use
New                                    \ reset target compiler
Target                                 \ switch into target compilation mode and context
include constants.f                    \ MicroCore Register addresses and bits
#code trap-vector code-origin
                0 data-origin

include forth.f
include debugger.f

: IntServer  ( -- )   di ;

#reset USR: reset   ['] init nop     BRANCH ;USR  \ compile branch to TEST at reset vector location
#isr   USR: isr     IntServer          IRET ;USR
#esr   USR: esr     r> 1- >r                ;     \ retry instruction
#break USR: break   ['] debugger nop BRANCH ;USR

Host                                   \ back into the Host environment

VHDL-file ..\debug_program.VHD            \ save a VHDL "code-Rom"

\ byte-file debugger.bin .( Image written to debugger.bin ) cr 
\ sym-file debugger.sym .( Symbols written to debugger.sym ) cr

\ bye
